summaryrefslogtreecommitdiffhomepage
path: root/gobgpd
diff options
context:
space:
mode:
authorISHIDA Wataru <ishida.wataru@lab.ntt.co.jp>2015-04-04 23:46:01 +0000
committerFUJITA Tomonori <fujita.tomonori@lab.ntt.co.jp>2015-04-14 08:10:28 +0900
commit75f835725deb42b00d5f746828f2738d15e3bc4f (patch)
tree5294cc59377f51896fd75a57cdb776f5e2f8bf54 /gobgpd
parent18bbb843d2e025af8e1ffd33b7c9a09d1a19c565 (diff)
api: use gRPC instead of REST
Signed-off-by: ISHIDA Wataru <ishida.wataru@lab.ntt.co.jp>
Diffstat (limited to 'gobgpd')
-rw-r--r--gobgpd/main.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/gobgpd/main.go b/gobgpd/main.go
index 090828eb..e8922226 100644
--- a/gobgpd/main.go
+++ b/gobgpd/main.go
@@ -143,9 +143,9 @@ func main() {
bgpServer := server.NewBgpServer(bgp.BGP_PORT)
go bgpServer.Serve()
- // start Rest Server
- restServer := api.NewRestServer(api.REST_PORT, bgpServer.RestReqCh)
- go restServer.Serve()
+ // start grpc Server
+ grpcServer := api.NewGrpcServer(api.GRPC_PORT, bgpServer.GrpcReqCh)
+ go grpcServer.Serve()
var bgpConfig *config.Bgp = nil
var policyConfig *config.RoutingPolicy = nil